<?php
/**
 * Roja45Quotations.
 *
 * @category  Roja45Quotations
 *
 * @author    Roja45 <support@roja45.com>
 * @copyright 2016 Roja45
 * @license   license.txt
 *
 * @link      http://www.roja45.com/
 *
 * 2016 ROJA45 - All rights reserved.
 *
 * DISCLAIMER
 * Changing this file will render any support provided by us null and void.
 */

/**
 * Roja45Quotations.
 *
 * @category  Class
 *
 * @author    Roja45 <support@roja45.com>
 * @copyright 2016 Roja45
 * @license   license.txt
 *
 * @link      http://www.roja45.com/
 *
 * 2016 ROJA45 - All rights reserved.
 *
 * DISCLAIMER
 * Changing this file will render any support provided by us null and void.
 */

spl_autoload_register(function ($class_name) {
    if (file_exists(_PS_MODULE_DIR_ . 'roja45quotations/classes/' . $class_name . '.php')) {
        require_once _PS_MODULE_DIR_ . 'roja45quotations/classes/' . $class_name . '.php';
    } elseif (Tools::substr($class_name, 0, 10) == 'ReCaptcha\\') {
        $class = str_replace('\\', '/', $class_name);
        $path = dirname(_PS_MODULE_DIR_ . 'roja45quotations/vendor/ReCaptcha').'/'.$class.'.php';
        if (is_readable($path)) {
            require_once $path;
        }
    } elseif (0 === strpos($class_name, 'Html2Text')) {
        if (file_exists(_PS_MODULE_DIR_ . 'roja45quotations/vendor/Html2Text/' . $class_name . '.php')) {
            require_once _PS_MODULE_DIR_ . 'roja45quotations/vendor/Html2Text/' . $class_name . '.php';
        }
    } else {
        return;
    }
});

class Roja45Quotations extends Module
{
    const TOPIC = 'UNSET';

    private $postErrors = array();

    public function __construct()
    {
        $this->name = 'roja45quotations';
        $this->tab = 'front_office_features';
        $this->version = '1.1.2';
        $this->author = 'Roja45';
        $this->is_eu_compatible = 1;
        $this->need_instance = 1;
        $this->bootstrap = true;
        $this->tabClassName = 'AdminQuotations';

        parent::__construct();

        $this->displayName = $this->l('Roja45: Quotations');
        $this->description = $this->l('Enable product quotations for customers, with custom forms and integration with Prestashop Customer Service system.');
        $this->ps_versions_compliancy = array('min' => '1.5', 'max' => _PS_VERSION_);
        $this->confirmUninstall = $this->l('Are you sure you want to delete all saved details?');
        $this->secure_key = Tools::encrypt($this->name);
    }

    public function install()
    {
        if (!parent::install()
            || !$this->registerHook('actionAdminControllerSetMedia')
            || !$this->registerHook('displayHeader')
            || !$this->registerHook('displayTopColumn')
            || !$this->registerHook('displayProductButtons')
            || !$this->registerHook('displayProductListReviews')
            || !$this->registerHook('displayRoja45ModuleManager')
            || !$this->registerHook('displayBackOfficeFooter')
            || !$this->setGlobalVars()
            || !$this->installDb()
            || !$this->installTabs()
        ) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!$this->uninstallDb()
            || !$this->uninstallTabs()
            || !$this->removeGlobalVars()
            || !parent::uninstall()
        ) {
            return false;
        }
        return true;
    }

    public function clearCache()
    {
        parent::_clearCache('displayHeader.tpl', 'roja45quotations-header');
        parent::_clearCache('displayTopColumn.tpl', 'roja45quotations-top-column');
        parent::_clearCache('displayProductButtons.tpl', 'roja45quotations-product-buttons');
        parent::_clearCache('displayFunctionalButtons.tpl', 'roja45quotation-functional-buttons');
    }

    public function getContent()
    {
        $html = '';
        if (Tools::isSubmit('submitConfiguration')) {
            $this->postValidation();

            if (!count($this->postErrors)) {
                $html .= $this->displayConfirmation($this->l('Settings updated'));
            } else {
                foreach ($this->postErrors as $err) {
                    $html .= $this->displayError($err);
                }
            }
        } else {
            $html .= '<br/>';
        }

        $this->smarty->assign(array(
            'topic' => self::TOPIC,
        ));
        $html .= $this->display(__FILE__, 'hookRoja45HeaderFree.tpl');
        $html .= $this->display(__FILE__, 'displayAdBlock.tpl');
        $html .= $this->renderModuleForm();

        return $html;
    }

    public function hookDisplayHeader($params)
    {
        if (!isset($this->context->controller->php_self)) {
            return;
        }
        $enabled_products = $this->getEnabledProducts();
        if (Configuration::get('PS_CATALOG_MODE')) {
            $this->context->controller->addJS($this->_path.'views/js/roja45quotations_catalogue.js');
        } elseif (($this->context->controller->php_self == 'product') && (Configuration::get('ROJA45_QUOTATIONS_REQUEST_TYPE')==1)) {
            $id_product = Tools::getValue('id_product');
            if (count($enabled_products) > 0 && in_array($id_product, $enabled_products)) {
                $this->context->controller->addJS($this->_path.'views/js/roja45quotations.js');
            }
        } elseif (($this->context->controller->php_self == 'order') && (Configuration::get('ROJA45_QUOTATIONS_REQUEST_TYPE')==2)) {
            $this->context->controller->addJS($this->_path.'views/js/roja45quotations_order.js');
            $this->smarty->assign(
                array(
                    'roja45quotations_cart_products' => Tools::jsonEncode($params['cart']->getProducts()),
                )
            );
        } elseif (count($enabled_products)) {
            $this->context->controller->addJS($this->_path.'views/js/roja45quotations.js');
        }

        $this->context->controller->addCSS($this->_path.'views/css/roja45quotations.css', 'all');
        $this->context->controller->addJS($this->_path.'views/js/validate.js');
        $this->context->controller->addJqueryUI('ui.effect');
        $this->context->controller->addJqueryUI('ui.datepicker');

        $controller_url = $this->context->link->getModuleLink(
            'roja45quotations',
            'QuotationsFront',
            array(),
            true
        );

        $roja45quotations_enable_captcha = Configuration::get('ROJA45_QUOTATIONS_ENABLE_CAPTCHA');
        if (count($enabled_products)==0) {
            $roja45quotations_enable_captcha = 0;
        }
        $this->smarty->assign(
            array(
                'roja45_quotations_enabled_products' => Tools::jsonEncode($enabled_products),
                'roja45quotations_type' => Configuration::get('ROJA45_QUOTATIONS_REQUEST_TYPE'),
                'roja45quotations_controller' => $controller_url,
            )
        );

        return $this->display(__FILE__, 'displayHeader.tpl', 'roja45quotations-header');
    }

    public function hookDisplayTopColumn($params)
    {
        $html = '';
        if (!isset($this->context->controller->php_self)) {
            return;
        }

        $enabled_products = $this->getEnabledProducts();
        if ($this->context->controller->php_self == 'product') {

        } elseif ($this->context->controller->php_self == 'order') {

        } else {

        }

        if ($enabled_products) {
            $form_config = $this->getForm();
            $form = $this->buildForm($form_config);
            $controller_url = $this->context->link->getModuleLink('roja45quotations', 'QuotationsFront', array(), true);
            $this->smarty->assign(
                array(
                    'id_language' => $this->context->language->id,
                    'form' => $form,
                    'columns' => $form_config['cols'],
                    'col_width' => 12 / $form_config['cols'],
                    'sl_country' => (int) Tools::getCountry(),
                    'enabled_products' => Tools::jsonEncode($enabled_products),
                    'roja45quotations_controller' => $controller_url,
                    'roja45quotations_type' => Configuration::get('ROJA45_QUOTATIONS_REQUEST_TYPE'),
                )
            );
            $html .= $this->display(__FILE__, 'displayTopColumn.tpl', 'roja45quotations-top-column');
        }

        return $html;
    }

    public function hookDisplayProductButtons($params)
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            $html = '';
            if (!isset($this->context->controller->php_self)) {
                return;
            }

            $enabled_products = $this->getEnabledProducts();
            $id_product = $params['product']->id;
            if (in_array($id_product, $enabled_products)) {
                $this->smarty->assign(array(
                    'TMP' => '',
                ));

                $html .= $this->display(__FILE__, 'displayProductButtons.tpl', $this->getCacheId('roja45quotation-product-buttons'));
            }

            return $html;
        }
    }

    public function hookDisplayProductListFunctionalButtons($params)
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            $html = '';
            if (!isset($this->context->controller->php_self)) {
                return;
            }

            $enabled_products = $this->getEnabledProducts();
            $id_product = $params['product']['id_product'];
            if (in_array($id_product, $enabled_products)) {
                $this->smarty->assign(array(
                    'id_product' => $id_product,
                ));

                $html .= $this->display(__FILE__, 'displayFunctionalButtons.tpl', $this->getCacheId('roja45quotation-functional-buttons'));
            }

            return $html;
        }
    }
    public function hookDisplayProductListReviews($params)
    {
        return $this->hookDisplayProductListFunctionalButtons($params);
    }

    public function hookActionAdminControllerSetMedia($params)
    {
        if ($this->context->controller->controller_name == 'AdminModules' && Tools::getValue('configure') == $this->name) {
            $this->context->controller->addJqueryPlugin('growl');
            $this->context->controller->addJS($this->_path.'views/js/validate.js');
            $this->context->controller->addJS($this->_path.'views/js/roja45moduleadmin.js');
            $this->context->controller->addCSS($this->_path.'views/css/roja45moduleadmin.css');
            $this->context->controller->addJqueryUi('ui.dialog');
            if (version_compare(_PS_VERSION_, '1.6.0.3', '>=') === true) {
                $this->context->controller->addjqueryPlugin('sortable');
            } elseif (version_compare(_PS_VERSION_, '1.6.0', '>=') === true) {
                $this->context->controller->addJS(_PS_JS_DIR_.'jquery/plugins/jquery.sortable.js');
            }
        }
    }

    public function hookDisplayRoja45ModuleManager($params)
    {
        $return = $this->name;

        return $return;
    }

    public function hookDisplayBackOfficeFooter($params)
    {
        return $this->display(__FILE__, 'hookRoja45ModalDialogs.tpl');
    }

    public function getEnabledProducts()
    {
        $product_ids = [];
        $sql = 'SELECT id_product FROM `'._DB_PREFIX_.'roja45_product_quotations` WHERE enabled = 1';

        if ($results = Db::getInstance()->ExecuteS($sql)) {
            foreach ($results as $row) {
                $product_ids[$row['id_product']] = $row['id_product'];
            }

            return $product_ids;
        } else {
            return [];
        }
    }

    private function buildForm($form_config)
    {
        $id_language = $this->context->language->id;
        $form = [];
        foreach ($form_config['fields'] as $column) {
            $form[0] = [];
            $form[0]['settings'] = [];
            $form[0]['fields'] = [];

            if (isset($form_config['titles']['form_element_column_title_' . 1])) {
                $form[0]['settings']['column_heading'] = $form_config['titles']['form_element_column_title_' . 1];
            }

            foreach ($column as $pos => $field) {
                $form_field = [];
                $form_field['id'] = $field['id'];
                $form_field['name'] = $field['name'];
                $form_field['type'] = $field['type'];
                if (isset($field['pos'])) {
                    $form_field['position'] = $field['pos'];
                }

                $config = [];
                parse_str($field['configuration'], $config);
                $form_field['required'] = $config['form_element_required'];

                if (isset($config['form_element_validation'])) {
                    $form_field['validation'] = $config['form_element_validation'];

                    // TODO - need to convert back to string here?
                    if ($form_field['validation'] == 'custom') {
                        $form_field['custom_regex'] = $config['form_element_validation_custom'];
                    } else {
                        $form_field['custom_regex'] = '';
                    }
                }

                if ($form_field['type'] == 'SELECT') {
                    if ($config['form_element_contents'] == 1) {
                        $exploded = explode("\n", urldecode($config['form_element_select_options_' . $id_language]));
                        $options = [];
                        foreach ($exploded as $key => $option) {
                            $options[$key]['id'] = Tools::strtoupper(trim($option));
                            $options[$key]['name'] = $option;
                        }
                        $form_field['options'] = $options;
                        $form_field['key_options'] = 'id';
                        $form_field['value_options'] = 'name';
                    } elseif ($config['form_element_contents'] == 2) {
                        if (Configuration::get('PS_RESTRICT_DELIVERED_COUNTRIES')) {
                            $countries = Carrier::getDeliveredCountries($this->context->language->id, true, true);
                        } else {
                            $countries = Country::getCountries($this->context->language->id, true);
                        }
                        $form_field['options'] = $countries;
                        $form_field['key_options'] = 'id_country';
                        $form_field['value_options'] = 'name';
                    }
                }
                if ($form_field['type'] == 'TEXTAREA') {
                    $form_field['rows'] = $config['form_element_rows_' . $id_language];
                }
                if ($form_field['type'] == 'DATE') {
                    $form_field['format'] = $config['form_element_date_format'];
                }
                $form_field['label'] = $config['form_element_label_' . $id_language];
                $form_field['description'] = $config['form_element_description_' . $id_language];

                if (isset($config['form_element_size'])) {
                    $form_field['size'] = $config['form_element_size'];
                } else {
                    $form_field['size'] = '';
                }

                if (isset($config['form_element_class'])) {
                    $form_field['class'] = $config['form_element_class'];
                } else {
                    $form_field['class'] = '';
                }
                if (isset($config['form_element_length'])) {
                    $form_field['maxlength'] = $config['form_element_length'];
                } else {
                    $form_field['maxlength'] = 255;
                }
                if (isset($config['form_element_prefix_' . $id_language]) && Tools::strlen($config['form_element_prefix_' . $id_language]) > 0) {
                    $form_field['prefix'] = $config['form_element_prefix_' . $id_language];
                } else {
                    $form_field['prefix'] = null;
                }
                if (isset($config['form_element_suffix_' . $id_language]) && Tools::strlen($config['form_element_suffix_' . $id_language]) > 0) {
                    $form_field['suffix'] = $config['form_element_suffix_' . $id_language];
                } else {
                    $form_field['suffix'] = null;
                }
                $form[0]['fields'][$pos] = $form_field;
            }
        }
        return $form;
    }

    public function getForm()
    {
        $form = [];
        $sql = 'SELECT * FROM `'._DB_PREFIX_.'roja45_quotation_form` WHERE id_shop ='.$this->context->shop->id;
        if ($row = Db::getInstance()->getRow($sql)) {
            $form['id'] = $row['id_quotation_form'];
            $form['cols'] = $row['form_columns'];
            // explode titles.
            $titles = [];
            parse_str($row['form_column_titles'], $titles);

            $form['titles'] = $titles;

            $sql = 'SELECT form_element_id as id, form_element_name as name, form_element_type as type, form_element_column as col, form_element_deletable as deletable, form_element_config as configuration
                    FROM `'._DB_PREFIX_.'roja45_quotation_form_element` WHERE id_quotation_form = '.$form['id'];
            // TODO add orderby
            if ($results = Db::getInstance()->ExecuteS($sql)) {
                foreach ($results as $row) {
                    $form['fields'][$row['col']][] = $row;
                }
            }
        }
        return $form;
    }

    private function installDb()
    {
        $return = true;
        try {
            // TODO - product_quotations table - Indicate that the product is quote enabled.    (store enabled, requires db class)
            $sql = '
            CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'roja45_product_quotations` (
              `id_product` int(10) unsigned NOT NULL auto_increment,
              `enabled` tinyint(1) NOT NULL DEFAULT \'0\',
              PRIMARY KEY (`id_product`)
            ) ENGINE=`'._MYSQL_ENGINE_.'` DEFAULT CHARSET=UTF8;';
            $return = (bool) Db::getInstance()->execute($sql);

            $sql = '
            CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'roja45_quotation_form` (
              `id_quotation_form` int(10) unsigned NOT NULL auto_increment,
              `id_shop` int(10) unsigned NOT NULL,
              `form_columns` int(10) NOT NULL,
              `form_column_titles` varchar(255) NOT NULL,
              PRIMARY KEY (`id_quotation_form`, `id_shop`)
            ) ENGINE=`'._MYSQL_ENGINE_.'` DEFAULT CHARSET=UTF8;';
            $return &= (bool) Db::getInstance()->execute($sql);
            $sql = '
            CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'roja45_quotation_form_element` (
              `id_quotation_form_element` int(10) unsigned NOT NULL auto_increment,
              `id_quotation_form` int(10) unsigned NOT NULL,
              `form_element_id` varchar(255) NOT NULL,
              `form_element_name` varchar(255) NOT NULL,
              `form_element_type` varchar(255),
              `form_element_column` int(1) NOT NULL,
              `form_element_position` int(10) NOT NULL,
              `form_element_deletable` tinyint(1) NOT NULL,
              `form_element_config` text NOT NULL,
              PRIMARY KEY (`id_quotation_form_element`, `id_quotation_form`)
            ) ENGINE=`'._MYSQL_ENGINE_.'` DEFAULT CHARSET=UTF8;';
            $return &= (bool) Db::getInstance()->execute($sql);

            Db::getInstance()->insert(
                'roja45_quotation_form',
                array(
                    'id_shop' => (int) $this->context->shop->id,
                    'form_columns' => 1,
                )
            );

            $id_form = Db::getInstance()->Insert_ID();
            $languages = Language::getLanguages(true);
            $contact_name_config = 'form_element_name=ROJA45_CONTACT_NAME&form_element_size=&form_element_required=1&form_element_validation=isName&form_element_validation_custom=&';
            $contact_email_config = 'form_element_name=ROJA45_CONTACT_EMAIL&form_element_size=&form_element_required=1&form_element_validation=isEmail&form_element_validation_custom=&';
            foreach ($languages as $language) {
                $contact_name_config .= 'form_element_label_'.$language['id_lang'].'=Contact+Name&form_element_description_'.$language['id_lang'].'=Enter+your+full+name&';
                $contact_email_config .= 'form_element_label_'.$language['id_lang'].'=Email+Address&form_element_description_'.$language['id_lang'].'=Enter+your+email+address&';
            }
            $contact_name_config = Tools::substr($contact_name_config, 0, Tools::strlen($contact_name_config)-1);
            $contact_email_config = Tools::substr($contact_email_config, 0, Tools::strlen($contact_name_config)-1);
            Db::getInstance()->insert(
                'roja45_quotation_form_element',
                array(
                    'id_quotation_form' => (int) $id_form,
                    'form_element_id' => 'contact_name_1',
                    'form_element_name' => 'ROJA45_CONTACT_NAME',
                    'form_element_type' => 'TEXT',
                    'form_element_column' => 1,
                    'form_element_position' => 0,
                    'form_element_deletable' => 0,
                    'form_element_config' => pSQL($contact_name_config),
                )
            );

            Db::getInstance()->insert(
                'roja45_quotation_form_element',
                array(
                    'id_quotation_form' => (int) $id_form,
                    'form_element_id' => 'contact_email_1',
                    'form_element_name' => 'ROJA45_CONTACT_EMAIL',
                    'form_element_type' => 'TEXT',
                    'form_element_column' => 1,
                    'form_element_position' => 1,
                    'form_element_deletable' => 0,
                    'form_element_config' => pSQL($contact_email_config),
                )
            );

            return $return;
        } catch (Exception $e) {
            return false;
        }
    }

    private function setGlobalVars()
    {
        Configuration::updateGlobalValue('ROJA45_QUOTATIONS_ENABLED', '0');
        Configuration::updateGlobalValue('ROJA45_QUOTATIONS_EMAIL', '');
        Configuration::updateGlobalValue('ROJA45_QUOTATIONS_COLUMNS', '1');
        Configuration::updateGlobalValue('ROJA45_QUOTATIONS_REQUEST_TYPE', 1);
        Configuration::updateGlobalValue('ROJA45_QUOTATIONS_DELETETABLES', 0);
        return true;
    }

    private function installTabs()
    {
        $id_tab = Tab::getIdFromClassName($this->tabClassName);
        if (!$id_tab) {
            $tab = new Tab();
            $tab->active = 0;
            $tab->class_name = $this->tabClassName;
            $tab->module = $this->name;
            $tab->name = array();
            foreach (Language::getLanguages(true) as $lang) {
                $tab->name[$lang['id_lang']] = 'Roja45 Quotations';
            }
            $tab->add();
        }
        return true;
    }

    private function uninstallDb()
    {
        try {
            if (Configuration::get('ROJA45_QUOTATIONS_DELETETABLES')==0) {
                return  Db::getInstance()->execute('
                    DROP TABLE IF EXISTS
                    `'._DB_PREFIX_.'roja45_product_quotations`,
                    `'._DB_PREFIX_.'roja45_quotation_form`,
                    `'._DB_PREFIX_.'roja45_quotation_form_element`'
                );
            } else {
                Configuration::updateGlobalValue('ROJA45_QUOTATIONS_UPGRADE_AVAILABLE', 1);
                return true;
            }
        } catch (Exception $e) {
            return false;
        }
    }

    private function uninstallTabs()
    {
        $id_tab = Tab::getIdFromClassName($this->tabClassName);
        if ($id_tab) {
            $tab = new Tab($id_tab);
            $tab->delete();
        }
        return true;
    }

    private function removeGlobalVars()
    {
        if (Configuration::get('ROJA45_QUOTATIONS_DELETETABLES')==0) {
            Configuration::deleteByName('ROJA45_QUOTATIONS_EMAIL');
            Configuration::deleteByName('ROJA45_QUOTATIONS_CONTACT_NAME');
            Configuration::deleteByName('ROJA45_QUOTATIONS_CONTACT_BCC');
            Configuration::deleteByName('ROJA45_QUOTATIONS_DELETETABLES');
            Configuration::deleteByName('ROJA45_QUOTATIONS_UPGRADE_AVAILABLE');
        }

        return true;
    }


    private function renderModuleForm()
    {
        $html = '';

        $options = array();
        foreach (Product::getProducts($this->context->language->id, 0, 0, 'id_product', 'ASC') as $product) {
            $options[] = array(
                'id_product' => (int) $product['id_product'],
                'name' => $product['name'],
            );
        }

        $form = $this->getForm();
        $tpl = $this->context->smarty->createTemplate($this->getTemplatePath('configuration.tpl'));
        $tpl->assign(
            array(
                'url' => $this->context->link->getAdminLink('AdminQuotations'),
                'languages' => $this->context->controller->getLanguages(),
                'defaultFormLanguage' => (int)Configuration::get('PS_LANG_DEFAULT'),
                'link' => $this->context->link,
                'contacts' => Contact::getContacts($this->context->language->id),
                'form' => $form,
                'columns' => 1,
                //'col_width' => 12 / $form['cols'],
                'col_width' => 12,
                'defaultFormLanguage' => (int) Configuration::get('PS_LANG_DEFAULT'),
                'products' => array(
                    'label' => $this->l('Enabled Product List'),
                    'hint' => $this->l('Select the products for which you would like enable quotations.'),
                    'name' => 'ROJA45_QUOTATIONS_ENABLED_PRODUCTS',
                    'required' => true,
                    'size' => '20',
                    'options' => array(
                        'query' => $options,
                        'id' => 'id_product',
                        'name' => 'name',
                    ),
                ),
                'text_input' => array(
                    'name' => 'TEXT_FIELD_LABEL',
                    'id' => 'TEST_ID',
                    'type' => 'text',
                    //'maxchar' => '10',
                    'size' => '20',
                    'maxlength' => '10',
                    'readonly' => '0',
                   // 'prefix' => 'TE',
                    //'suffix' => 'ST',
                    'class' => 'test-class',
                   // 'string_format' => 'test-format',
                   // 'disabled' => '0',
                   // 'autocomplete' => '0',
                    'required' => '1',
                   // 'placeholder' => '',
                ),
                'fields_value' => $this->getModuleConfigFieldsValues(),
            )
        );

        $html .= $tpl->fetch();
        return $html;
    }

    private function postValidation()
    {
        if (Tools::isSubmit('submitConfiguration')) {
            if (!Tools::getValue('ROJA45_QUOTATION_ENABLED')) {
                $this->postErrors[] = $this->l('Account Name is required.');
            }
        }
    }

    private function getModuleConfigFieldsValues()
    {
        return array(
            'ROJA45_QUOTATIONS_USE_CS' => Tools::getValue('ROJA45_QUOTATIONS_USE_CS', Configuration::get('ROJA45_QUOTATIONS_USE_CS')),
            'ROJA45_QUOTATIONS_CS_ACCOUNT' => Tools::getValue('ROJA45_QUOTATIONS_CS_ACCOUNT', Configuration::get('ROJA45_QUOTATIONS_CS_ACCOUNT')),
            'ROJA45_QUOTATIONS_EMAIL' => Tools::getValue('ROJA45_QUOTATIONS_EMAIL', Configuration::get('ROJA45_QUOTATIONS_EMAIL')),
            'ROJA45_QUOTATIONS_CONTACT_NAME' => Tools::getValue('ROJA45_QUOTATIONS_CONTACT_NAME', Configuration::get('ROJA45_QUOTATIONS_CONTACT_NAME')),
            'ROJA45_QUOTATIONS_CONTACT_BCC' => Tools::getValue('ROJA45_QUOTATIONS_CONTACT_BCC', Configuration::get('ROJA45_QUOTATIONS_CONTACT_BCC')),
            'ROJA45_QUOTATIONS_ENABLE_CAPTCHA' => Tools::getValue('ROJA45_QUOTATIONS_ENABLE_CAPTCHA', Configuration::get('ROJA45_QUOTATIONS_ENABLE_CAPTCHA')),
            'ROJA45_QUOTATIONS_ALWAYS_DISPLAY' => Tools::getValue('ROJA45_QUOTATIONS_ALWAYS_DISPLAY', Configuration::get('ROJA45_QUOTATIONS_ALWAYS_DISPLAY')),
            'ROJA45_QUOTATIONS_RECAPTCHA_SITE' => Tools::getValue('ROJA45_QUOTATIONS_RECAPTCHA_SITE', Configuration::get('ROJA45_QUOTATIONS_RECAPTCHA_SITE')),
            'ROJA45_QUOTATIONS_REQUEST_TYPE' => Tools::getValue('ROJA45_QUOTATIONS_REQUEST_TYPE', Configuration::get('ROJA45_QUOTATIONS_REQUEST_TYPE')),
            'ROJA45_QUOTATIONS_RECAPTCHA_SECRET' => Tools::getValue('ROJA45_QUOTATIONS_RECAPTCHA_SECRET', Configuration::get('ROJA45_QUOTATIONS_RECAPTCHA_SECRET')),
            'ROJA45_QUOTATIONS_DISPLAY_LABEL' => Tools::getValue('ROJA45_QUOTATIONS_DISPLAY_LABEL', Configuration::get('ROJA45_QUOTATIONS_DISPLAY_LABEL')),
            'ROJA45_QUOTATIONS_DELETETABLES' => Tools::getValue('ROJA45_QUOTATIONS_DELETETABLES', Configuration::get('ROJA45_QUOTATIONS_DELETETABLES')),
            'ROJA45_QUOTATIONS_ENABLED_PRODUCTS' => $this->getEnabledProducts(),
        );
    }
}
